@@ -18,7 +18,7 @@ from GameSentenceMiner.web.service import handle_texthooker_button
 
 # Import from new modules
 from GameSentenceMiner.web.events import (
-    EventItem, EventManager, EventProcessor, event_manager, event_queue, event_processor
+    EventManager, event_manager
 )
 from GameSentenceMiner.web.stats import (
     is_kanji, interpolate_color, get_gradient_color, calculate_kanji_frequency,
@@ -137,7 +137,11 @@ def get_data():
 
 @app.route('/get_ids', methods=['GET'])
 def get_ids():
-    return jsonify(event_manager.get_ids())
+    asyncio.run(check_for_lines_outside_replay_buffer())
+    return jsonify({
+        "ids": list(event_manager.get_ids()),
+        "timed_out_ids": list(event_manager.timed_out_ids)
+    })
 
 
 @app.route('/clear_history', methods=['POST'])
@@ -148,6 +152,14 @@ def clear_history():
     return jsonify({'message': 'History cleared successfully'}), 200
 
 
+async def check_for_lines_outside_replay_buffer():
+    time_window = datetime.datetime.now() - datetime.timedelta(seconds=gsm_state.replay_buffer_length) - datetime.timedelta(seconds=5)
+    # logger.info(f"Checking for lines outside replay buffer time window: {time_window}")
+    lines_outside_buffer = [line.id for line in event_manager.get_events() if line.time < time_window]
+    # logger.info(f"Lines outside replay buffer: {lines_outside_buffer}")
+    event_manager.remove_lines_by_ids(lines_outside_buffer, timed_out=True)
+    
+
 async def add_event_to_texthooker(line):
     new_event = event_manager.add_gameline(line)
     await websocket_server_thread.send_text({
@@ -157,6 +169,7 @@ async def add_event_to_texthooker(line):
     })
     if get_config().advanced.plaintext_websocket_port:
         await plaintext_websocket_server_thread.send_text(line.text)
+    await check_for_lines_outside_replay_buffer()
 
 
 async def send_word_coordinates_to_overlay(boxes):
@@ -222,14 +235,33 @@ def translate_line():
     if event_id is None:
         return jsonify({'error': 'Missing id'}), 400
     
+    
+    if get_config().ai.custom_texthooker_prompt:
+        prompt = get_config().ai.custom_texthooker_prompt.strip()
+    else:
+        prompt = f"""
+        **Professional Game Localization Task**
+
+        **Task Directive:**
+        Translate ONLY the provided line of game dialogue specified below into natural-sounding, context-aware {get_config().general.get_native_language_name()}. The translation must preserve the original tone and intent of the source.
+
+        **Output Requirements:**
+        - Provide only the single, best {get_config().general.get_native_language_name()} translation.
+        - Use expletives if they are natural for the context and enhance the translation's impact, but do not over-exaggerate.
+        - Do not include notes, alternatives, explanations, or any other surrounding text. Absolutely nothing but the translated line.
+
+        **Line to Translate:**
+        """
+
     if not get_config().ai.is_configured():
         return jsonify({'error': 'AI translation is not properly configured. Please check your settings in the "AI" Tab.'}), 400
     line = get_line_by_id(event_id)
     if line is None:
         return jsonify({'error': 'Invalid id'}), 400
     line_to_translate = text if text else line.text
-    translation = get_ai_prompt_result(get_all_lines(), line_to_translate,
-                                       line, get_current_game())
+    translation = get_ai_prompt_result(
+        get_all_lines(), line_to_translate, line, get_current_game(), custom_prompt=prompt
+    )
     line.set_TL(translation)
     return jsonify({'TL': translation}), 200
 
@@ -249,19 +281,20 @@ def translate_multiple():
     
     language = get_config().general.get_native_language_name() if get_config().general.native_language else "English"
     
+    
     translate_multiple_lines_prompt = f"""
-**Professional Game Localization Task**
-Translate the following lines of game dialogue into natural-sounding, context-aware {language}:
+    **Professional Game Localization Task**
+    Translate the following lines of game dialogue into natural-sounding, context-aware {language}:
 
-**Output Requirements**
-- Maintain the original tone and style of the dialogue.
-- Ensure that the translation is contextually appropriate for the game.
-- Pay attention to character names and any specific terminology used in the game.
-- Maintain Formatting and newline structure of the given lines. It should be very human readable as a dialogue.
-- Do not include any notes, alternatives, explanations, or any other surrounding text. Absolutely nothing but the translated lines.
+    **Output Requirements**
+    - Maintain the original tone and style of the dialogue.
+    - Ensure that the translation is contextually appropriate for the game.
+    - Pay attention to character names and any specific terminology used in the game.
+    - Maintain Formatting and newline structure of the given lines. It should be very human readable as a dialogue.
+    - Do not include any notes, alternatives, explanations, or any other surrounding text. Absolutely nothing but the translated lines.
 
-**Lines to Translate:**
-"""
+    **Lines to Translate:**
+    """
 
     translation = get_ai_prompt_result(get_all_lines(), text,
                                         lines[0], get_current_game(), custom_prompt=translate_multiple_lines_prompt)
